@@ -1,12 +1,13 @@
 __author__ = "ContraxSuite, LLC; LexPredict, LLC"
 __copyright__ = "Copyright 2015-2021, ContraxSuite, LLC"
-__license__ = "https://github.com/LexPredict/lexpredict-lexnlp/blob/2.1.0/LICENSE"
-__version__ = "2.1.0"
+__license__ = "https://github.com/LexPredict/lexpredict-lexnlp/blob/2.3.0/LICENSE"
+__version__ = "2.3.0"
 __maintainer__ = "LexPredict, LLC"
 __email__ = "support@contraxsuite.com"
 
+
 import regex as re
-from typing import Generator
+from typing import Generator, List
 from decimal import Decimal
 from lexnlp.extract.common.annotations.percent_annotation import PercentAnnotation
 from lexnlp.extract.de.amounts import AmountParserDE
@@ -27,7 +28,7 @@ PERCENT_PTN = r"""
 PERCENT_PTN_RE = re.compile(PERCENT_PTN, re.IGNORECASE | re.MULTILINE | re.DOTALL | re.VERBOSE)
 
 
-def get_percents(text: str, float_digits: int = 4) -> Generator:
+def get_percents(text: str, float_digits: int = 4) -> Generator[dict, None, None]:
     """
     Get percent usages within text.
     :param text:
@@ -81,5 +82,12 @@ def get_percent_annotations(
         )
 
 
-def get_percent_list(*args, **kwargs):
-    return list(get_percents(*args, **kwargs))
+def get_percent_list(text: str, float_digits: int = 4) -> List[dict]:
+    return list(get_percents(text, float_digits))
+
+
+def get_percent_annotation_list(
+    text: str,
+    float_digits: int = 4,
+) -> List[PercentAnnotation]:
+    return list(get_percent_annotations(text, float_digits))
