@@ -8,14 +8,15 @@ Todo:
 
 __author__ = "ContraxSuite, LLC; LexPredict, LLC"
 __copyright__ = "Copyright 2015-2021, ContraxSuite, LLC"
-__license__ = "https://github.com/LexPredict/lexpredict-lexnlp/blob/2.1.0/LICENSE"
-__version__ = "2.1.0"
+__license__ = "https://github.com/LexPredict/lexpredict-lexnlp/blob/2.3.0/LICENSE"
+__version__ = "2.3.0"
 __maintainer__ = "LexPredict, LLC"
 __email__ = "support@contraxsuite.com"
 
+
 # pylint: disable=bare-except
 
-from typing import Generator
+from typing import Dict, Generator, List, Tuple, Union
 
 import regex as re
 from reporters_db import EDITIONS, REPORTERS
@@ -37,14 +38,26 @@ CITATION_PTN = r"""
 CITATION_PTN_RE = re.compile(CITATION_PTN, re.IGNORECASE | re.MULTILINE | re.DOTALL | re.VERBOSE)
 
 
-def get_citations(text: str, return_source=False, as_dict=False) -> Generator:
+def get_citations(
+    text: str,
+    return_source: bool = False,
+    as_dict: bool = False,
+) -> Generator[Union[Dict, Tuple], None, None]:
     """
-    Get citations.
-    :param text:
-    :param return_source:
-    :param as_dict:
-    :return: tuple or dict
-    (volume, reporter, reporter_full_name, page, page2, court, year[, source text])
+    Get a list of citations.
+
+    Args:
+        text (str):
+            An input string.
+
+        return_source (bool=False):
+            Whether to return the source.
+
+        as_dict (bool=False):
+            Whether to return a dictionary. If False (default), returns tuples.
+
+    Returns:
+        A list of tuples or dictionaries representing citations.
     """
     for ant in get_citation_annotations(text):
         if as_dict:
@@ -62,15 +75,45 @@ def get_citations(text: str, return_source=False, as_dict=False) -> Generator:
             yield item
 
 
-def get_citation_annotations(text: str) -> \
-        Generator[CitationAnnotation, None, None]:
+def get_citation_list(
+    text: str,
+    return_source: bool = False,
+    as_dict: bool = False,
+) -> List[Union[Dict, Tuple]]:
     """
-    Get citations.
-    :param text:
-    :param return_source:
-    :param as_dict:
-    :return: tuple or dict
-    (volume, reporter, reporter_full_name, page, page2, court, year[, source text])
+    Get a list of citations.
+
+    Args:
+        text (str):
+            An input string.
+
+        return_source (bool=False):
+            Whether to return the source.
+
+        as_dict (bool=False):
+            Whether to return a dictionary. If False (default), returns tuples.
+
+    Returns:
+        A list of tuples or dictionaries representing citations.
+    """
+    return list(
+        get_citations(
+            text=text,
+            return_source=return_source,
+            as_dict=as_dict,
+        )
+    )
+
+
+def get_citation_annotations(text: str) -> Generator[CitationAnnotation, None, None]:
+    """
+    Get citation annotations.
+
+    Args:
+        text (str):
+
+    Yields:
+        CitationAnnotations
     """
     for match in CITATION_PTN_RE.finditer(text):
         source_text, volume, reporter, \
@@ -102,3 +145,16 @@ def get_citation_annotations(text: str) -> \
             yield ant
         except KeyError:
             pass
+
+
+def get_citation_annotation_list(text: str) -> List[CitationAnnotation]:
+    """
+    Get citation annotations.
+
+    Args:
+        text (str):
+
+    Returns:
+        A list of CitationAnnotations.
+    """
+    return list(get_citation_annotations(text))
