@@ -8,11 +8,12 @@ Todo: -
 
 __author__ = "ContraxSuite, LLC; LexPredict, LLC"
 __copyright__ = "Copyright 2015-2021, ContraxSuite, LLC"
-__license__ = "https://github.com/LexPredict/lexpredict-lexnlp/blob/2.1.0/LICENSE"
-__version__ = "2.1.0"
+__license__ = "https://github.com/LexPredict/lexpredict-lexnlp/blob/2.3.0/LICENSE"
+__version__ = "2.3.0"
 __maintainer__ = "LexPredict, LLC"
 __email__ = "support@contraxsuite.com"
 
+
 import string
 from typing import Generator, List, Tuple, Union
 
@@ -50,10 +51,23 @@ class CopyrightEnParser(CopyrightEnStyleParser):
         return np_extractor.get_np_with_coords(sentence)
 
 
-def get_copyright(
+def get_copyrights(
     text: str,
     return_sources: bool = False
 ) -> Generator[Union[Tuple[str, str, str], Tuple[str, str, str, str]], None, None]:
+    """
+    Gets copyrights.
+
+    Args:
+        text (str):
+            An input string to search for copyrights.
+
+        return_sources (bool=False):
+            Whether to return the input text.
+
+    Yields:
+        Tuples representing copyright annotations.
+    """
     for ant in get_copyright_annotations(text, return_sources):
         if return_sources:
             yield ant.sign, ant.date, ant.name, ant.text
@@ -61,9 +75,60 @@ def get_copyright(
             yield ant.sign, ant.date, ant.name
 
 
-def get_copyright_annotations(text: str, return_sources=False) -> \
-        Generator[CopyrightAnnotation, None, None]:
-    for ant in CopyrightEnParser.get_copyright_annotations(text,
-                                                           return_sources):
+def get_copyright_list(
+    text: str,
+    return_sources: bool = False
+) -> List[Union[Tuple[str, str, str], Tuple[str, str, str, str]]]:
+    """
+    Gets copyrights.
+
+    Args:
+        text (str):
+            An input string to search for copyrights.
+
+        return_sources (bool=False):
+            Whether to return the input text.
+
+    Returns:
+        A list of tuples representing copyright annotations.
+    """
+    return list(get_copyrights(text, return_sources))
+
+
+def get_copyright_annotations(
+    text: str,
+    return_sources=False,
+) -> Generator[CopyrightAnnotation, None, None]:
+    """
+    Gets copyright annotations.
+
+    Args:
+        text (str):
+            An input string to search for copyrights.
+
+        return_sources (bool=False):
+            Whether to return the input text.
+
+    Yields:
+        CopyrightAnnotation
+    """
+    for ant in CopyrightEnParser.get_copyright_annotations(text, return_sources):
         ant.locale = 'en'
         yield ant
+
+
+def get_copyright_annotation_list(text: str, return_sources: bool = False) -> List[CopyrightAnnotation]:
+    """
+    Gets a list of copyright annotations.
+
+    Args:
+        text (str):
+            An input string to search for copyrights.
+
+        return_sources (bool=False):
+            Whether to return the input text.
+
+    Returns:
+        A list of CopyrightAnnotations
+    """
+    return list(get_copyright_annotations(text, return_sources))
