@@ -2,19 +2,18 @@
 
 This module implements basic Trademark extraction functionality in English relying on the pre-trained
 NLTK functionality, including POS tagger and NE (fuzzy) chunkers.
-
-Todo: -
 """
 
 __author__ = "ContraxSuite, LLC; LexPredict, LLC"
 __copyright__ = "Copyright 2015-2021, ContraxSuite, LLC"
-__license__ = "https://github.com/LexPredict/lexpredict-lexnlp/blob/2.1.0/LICENSE"
-__version__ = "2.1.0"
+__license__ = "https://github.com/LexPredict/lexpredict-lexnlp/blob/2.3.0/LICENSE"
+__version__ = "2.3.0"
 __maintainer__ = "LexPredict, LLC"
 __email__ = "support@contraxsuite.com"
 
+
 import re
-from typing import Generator
+from typing import Generator, List
 
 from lexnlp.extract.common.annotations.trademark_annotation import TrademarkAnnotation
 from lexnlp.extract.en.utils import NPExtractor
@@ -42,8 +41,13 @@ def get_trademarks(text: str) -> Generator[str, None, None]:
         yield ant.trademark
 
 
-def get_trademark_annotations(text: str) -> \
-        Generator[TrademarkAnnotation, None, None]:
+def get_trademark_list(text: str) -> List[str]:
+    """
+    """
+    return list(get_trademarks(text))
+
+
+def get_trademark_annotations(text: str) -> Generator[TrademarkAnnotation, None, None]:
     """
     Find trademarks in text.
     """
@@ -61,6 +65,11 @@ def get_trademark_annotations(text: str) -> \
                       coords[1] + phrase[1])
             if coords[1] >= len(text):
                 coords = (coords[0], len(text) - 1)
-            ant = TrademarkAnnotation(coords=coords,
-                                      trademark=tm.group())
+            ant = TrademarkAnnotation(coords=coords, trademark=tm.group())
             yield ant
+
+
+def get_trademark_annotation_list(text: str) -> List[TrademarkAnnotation]:
+    """
+    """
+    return list(get_trademark_annotations(text))
