@@ -5,17 +5,19 @@ Dates parser based on dateparser package
 
 __author__ = "ContraxSuite, LLC; LexPredict, LLC"
 __copyright__ = "Copyright 2015-2021, ContraxSuite, LLC"
-__license__ = "https://github.com/LexPredict/lexpredict-lexnlp/blob/2.1.0/LICENSE"
-__version__ = "2.1.0"
+__license__ = "https://github.com/LexPredict/lexpredict-lexnlp/blob/2.3.0/LICENSE"
+__version__ = "2.3.0"
 __maintainer__ = "LexPredict, LLC"
 __email__ = "support@contraxsuite.com"
 
+
 # pylint: disable=bare-except
 import datetime
 import string
 from typing import Optional, Dict, Any, Generator
-
 import regex as re
+
+# noinspection PyUnresolvedReferences
 from dateparser.data.date_translation_data.es import info
 
 from lexnlp.extract.all_locales.languages import Locale
@@ -23,11 +25,10 @@ from lexnlp.extract.common.annotations.date_annotation import DateAnnotation
 from lexnlp.extract.common.dates import DateParser
 
 
-months = ['january', 'february', 'march', 'april', 'may', 'june', 'july', 'august', 'september', 'october', 'november', 'december']
+months = ('january', 'february', 'march', 'april', 'may', 'june', 'july', 'august', 'september', 'october', 'november', 'december')
 ES_MONTHS = sorted([y.lower() for k, v in info.items() if k in months for y in v],
                    key=lambda i: (-len(i), i))
 
-# ES_ALPHABET = 'äöüẞ' + 'äöüẞ'.upper()
 ES_ALPHABET = ''
 DATE_MODEL_CHARS = []
 DATE_MODEL_CHARS.extend(ES_ALPHABET + string.ascii_letters)
@@ -105,16 +106,10 @@ parser = ESDateParser(
                          'DATE_ORDER': 'DMY'})
 
 
-def get_date_annotations(text: str,
-                         strict: Optional[bool] = None,
-                         locale: Optional[str] = '',
-                         _base_date: Optional[datetime.datetime] = None,
-                         _threshold: float = 0.50) -> Generator[DateAnnotation, None, None]:
-    strict = strict if strict is not None else False
-    yield from parser.get_date_annotations(text, Locale(locale), strict)
-
-
 get_dates = parser.get_dates
 
-
 get_date_list = parser.get_date_list
+
+get_date_annotations = parser.get_date_annotations
+
+get_date_annotation_list = parser.get_date_annotation_list
