@@ -1,10 +1,11 @@
 __author__ = "ContraxSuite, LLC; LexPredict, LLC"
 __copyright__ = "Copyright 2015-2021, ContraxSuite, LLC"
-__license__ = "https://github.com/LexPredict/lexpredict-lexnlp/blob/2.1.0/LICENSE"
-__version__ = "2.1.0"
+__license__ = "https://github.com/LexPredict/lexpredict-lexnlp/blob/2.3.0/LICENSE"
+__version__ = "2.3.0"
 __maintainer__ = "LexPredict, LLC"
 __email__ = "support@contraxsuite.com"
 
+
 import re
 from typing import List, Generator
 from lexnlp.extract.common.annotations.definition_annotation import DefinitionAnnotation
@@ -91,16 +92,18 @@ def make_es_definitions_parser():
 parser = make_es_definitions_parser()
 
 
-def get_definition_annotations(text: str, language=None) -> \
-        Generator[DefinitionAnnotation, None, None]:
-    yield from parser.parse(text, language if language else 'es')
+def get_definition_annotations(text: str, language: str = 'es') -> Generator[DefinitionAnnotation, None, None]:
+    yield from parser.parse(text, language)
 
 
-def get_definitions(text: str, language=None) -> Generator[dict, None, None]:
-    dfs = parser.parse(text, language if language else 'es')
-    for d in dfs:
-        yield d.to_dictionary()
+def get_definition_annotation_list(text: str, language: str = 'es') -> List[DefinitionAnnotation]:
+    return list(get_definition_annotations(text, language))
 
 
-def get_definition_list(text: str, language=None) -> List[DefinitionAnnotation]:
-    return parser.parse(text, language if language else 'es')
+def get_definitions(text: str, language: str = 'es') -> Generator[dict, None, None]:
+    for annotation in parser.parse(text, language):
+        yield annotation.to_dictionary()
+
+
+def get_definition_list(text: str, language: str = 'es') -> List[dict]:
+    return list(get_definitions(text, language))
