@@ -9,11 +9,12 @@ Todo:
 
 __author__ = "ContraxSuite, LLC; LexPredict, LLC"
 __copyright__ = "Copyright 2015-2021, ContraxSuite, LLC"
-__license__ = "https://github.com/LexPredict/lexpredict-lexnlp/blob/2.1.0/LICENSE"
-__version__ = "2.1.0"
+__license__ = "https://github.com/LexPredict/lexpredict-lexnlp/blob/2.3.0/LICENSE"
+__version__ = "2.3.0"
 __maintainer__ = "LexPredict, LLC"
 __email__ = "support@contraxsuite.com"
 
+
 import os
 import string
 import unicodedata
@@ -29,6 +30,8 @@ from lexnlp.nlp.en.segments.utils import build_document_distribution
 
 
 # Setup module path
+
+
 MODULE_PATH = os.path.dirname(os.path.abspath(__file__))
 
 # Load segmenters
@@ -75,15 +78,17 @@ def build_page_break_features(lines,
 
     # Simple checks
     line = lines[line_id]
+    line_stripped = line.strip()
+    len_line_stripped = len(line_stripped)
     feature_vector["page"] = 1 if "page" in line else 0
     feature_vector["PAGE"] = 1 if "PAGE" in line else 0
     feature_vector["Page"] = 1 if "Page" in line else 0
-    feature_vector["sw_page"] = 1 if line.strip().lower().startswith("page") else 0
-    feature_vector["sw_pg"] = 1 if line.strip().lower().startswith("pg") else 0
-    feature_vector["first_char_punct"] = (line.strip()[0] in string.punctuation) if len(line.strip()) > 0 else False
-    feature_vector["last_char_punct"] = (line.strip()[-1] in string.punctuation) if len(line.strip()) > 0 else False
-    feature_vector["first_char_number"] = (line.strip()[0] in string.digits) if len(line.strip()) > 0 else False
-    feature_vector["last_char_number"] = (line.strip()[-1] in string.digits) if len(line.strip()) > 0 else False
+    feature_vector["sw_page"] = 1 if line_stripped.lower().startswith("page") else 0
+    feature_vector["sw_pg"] = 1 if line_stripped.lower().startswith("pg") else 0
+    feature_vector["first_char_punct"] = (line_stripped[0] in string.punctuation) if len_line_stripped > 0 else False
+    feature_vector["last_char_punct"] = (line_stripped[-1] in string.punctuation) if len_line_stripped > 0 else False
+    feature_vector["first_char_number"] = (line_stripped[0] in string.digits) if len_line_stripped > 0 else False
+    feature_vector["last_char_number"] = (line_stripped[-1] in string.digits) if len_line_stripped > 0 else False
 
     # Build character vector
     for character in characters:
