@@ -7,21 +7,21 @@ Todo:
 
 __author__ = "ContraxSuite, LLC; LexPredict, LLC"
 __copyright__ = "Copyright 2015-2021, ContraxSuite, LLC"
-__license__ = "https://github.com/LexPredict/lexpredict-lexnlp/blob/2.1.0/LICENSE"
-__version__ = "2.1.0"
+__license__ = "https://github.com/LexPredict/lexpredict-lexnlp/blob/2.3.0/LICENSE"
+__version__ = "2.3.0"
 __maintainer__ = "LexPredict, LLC"
 __email__ = "support@contraxsuite.com"
 
+
 import os
 import pickle
-from typing import List, Generator, Any
 import regex as re
+from typing import Any, Generator, List
 
 # NLTK imports
 import nltk
 from nltk.corpus import wordnet
 
-
 MODULE_PATH = os.path.dirname(os.path.abspath(__file__))
 
 # Stopwords
